California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 51 - TRANSPORTATION. DISTRIBUTION OF EXISTING MOTOR VEHICLE SALES AND USE TAX. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245164 | PCL'S YES ON 50 AND 51 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1239911 | YES ON 51 PROJECT OF PLANNING & CONSERVATION LEAGUE, CONSERVATIONISTS, HIGHER ED, COMMUNITY GROUPS, HOME BUILDERS, TRANSPORTATION DEVELOPERS, INDIAN GAMING, OPEN SPACE LANDOWNERS, CLEAN ENGINE MAKERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1248158 | ORANGE COUNTY VOTERS FOR GOOD GOVERNMENT, YES ON PROP. 51 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1247731 | NO ON PROPOSITION 51 COMMITTEE | OPPOSE